@@ -8,16 +8,20 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.assets
 import aws_cdk.aws_certificatemanager
 import aws_cdk.aws_ec2
 import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
+import aws_cdk.aws_s3
+import aws_cdk.aws_s3_assets
 import aws_cdk.core
+import aws_cdk.cx_api
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-apigateway", "1.37.0", __name__[0:-6], "aws-apigateway@1.37.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-apigateway", "1.39.0", __name__[0:-6], "aws-apigateway@1.39.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
